==> prometheus-annotations-2.7.0-sources.jar: io/dekorate/prometheus/adapter/ServiceMonitorConfigAdapter.java <==
package io.dekorate.prometheus.adapter;

import java.lang.Integer;
import io.dekorate.project.Project;
import io.dekorate.prometheus.config.ServiceMonitorConfig;
import io.dekorate.prometheus.config.ServiceMonitorConfigBuilder;
import io.dekorate.project.BuildInfo;
import java.lang.Object;
import java.util.List;
import io.dekorate.prometheus.annotation.EnableServiceMonitor;
import java.lang.String;
import io.dekorate.project.ScmInfo;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ServiceMonitorConfigAdapter{
  public static io.dekorate.prometheus.config.ServiceMonitorConfig adapt(io.dekorate.prometheus.annotation.EnableServiceMonitor instance) {
    return newBuilder(instance).build();
  }
  public static io.dekorate.prometheus.config.ServiceMonitorConfigBuilder newBuilder(io.dekorate.prometheus.annotation.EnableServiceMonitor instance) {
    return new ServiceMonitorConfigBuilder(new io.dekorate.prometheus.config.ServiceMonitorConfig(null,
            null,
            instance.port(),
            instance.path(),
            instance.interval(),
            instance.honorLabels()));
  }
  public static io.dekorate.prometheus.config.ServiceMonitorConfig adapt(java.util.Map map) {
    return new io.dekorate.prometheus.config.ServiceMonitorConfig(
null,
null,
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("port", null) : null),
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("path", null) : null),
               (java.lang.Integer)(map instanceof Map ? ((Map)map).getOrDefault("interval", null) : null),
               (java.lang.Boolean)(map instanceof Map ? ((Map)map).getOrDefault("honorLabels", null) : null));
  }
  public static io.dekorate.prometheus.config.ServiceMonitorConfigBuilder newBuilder(java.util.Map map) {
    return new ServiceMonitorConfigBuilder(new io.dekorate.prometheus.config.ServiceMonitorConfig(
null,
null,
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("port", null) : null),
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("path", null) : null),
               (java.lang.Integer)(map instanceof Map ? ((Map)map).getOrDefault("interval", null) : null),
               (java.lang.Boolean)(map instanceof Map ? ((Map)map).getOrDefault("honorLabels", null) : null)));
  }
  public static java.lang.String[] toStringArray(java.lang.Object o) {
            if (o instanceof String[]) {
          return (String[]) o;
        }
        if (o instanceof String) {
          String s =  (String) o;
          return s.split(",[ ]*");
        }
        else if (o instanceof List) {
          List c = (List) o;
          String[] result = new String[c.size()]; 
          for (int i=0; i <= c.size(); i++) {
            result[i] = String.valueOf(c.get(i));
          }
          return result;
        }
        return new String[0];
    

  }
  
}

==> prometheus-annotations-2.11.4-sources.jar: io/dekorate/prometheus/adapter/ServiceMonitorConfigAdapter.java <==
package io.dekorate.prometheus.adapter;

import java.lang.Integer;
import io.dekorate.project.Project;
import io.dekorate.prometheus.config.ServiceMonitorConfig;
import io.dekorate.prometheus.config.ServiceMonitorConfigBuilder;
import io.dekorate.project.BuildInfo;
import java.lang.Object;
import java.util.List;
import io.dekorate.prometheus.annotation.EnableServiceMonitor;
import java.lang.String;
import io.dekorate.project.ScmInfo;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ServiceMonitorConfigAdapter{
  public static ServiceMonitorConfig adapt(EnableServiceMonitor instance) {
    return newBuilder(instance).build();
  }
  public static ServiceMonitorConfigBuilder newBuilder(io.dekorate.prometheus.annotation.EnableServiceMonitor instance) {
    return new ServiceMonitorConfigBuilder(new io.dekorate.prometheus.config.ServiceMonitorConfig(null,
            null,
            instance.port(),
            instance.path(),
            instance.interval(),
            instance.honorLabels()));
  }
  public static io.dekorate.prometheus.config.ServiceMonitorConfig adapt(Map map) {
    return new io.dekorate.prometheus.config.ServiceMonitorConfig(
null,
null,
               (String)(map instanceof Map ? ((Map)map).getOrDefault("port", null) : null),
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("path", null) : null),
               (Integer)(map instanceof Map ? ((Map)map).getOrDefault("interval", null) : null),
               (Boolean)(map instanceof Map ? ((Map)map).getOrDefault("honorLabels", null) : null));
  }
  public static io.dekorate.prometheus.config.ServiceMonitorConfigBuilder newBuilder(java.util.Map map) {
    return new ServiceMonitorConfigBuilder(new io.dekorate.prometheus.config.ServiceMonitorConfig(
null,
null,
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("port", null) : null),
               (java.lang.String)(map instanceof Map ? ((Map)map).getOrDefault("path", null) : null),
               (java.lang.Integer)(map instanceof Map ? ((Map)map).getOrDefault("interval", null) : null),
               (java.lang.Boolean)(map instanceof Map ? ((Map)map).getOrDefault("honorLabels", null) : null)));
  }
  public static java.lang.String[] toStringArray(Object o) {
            if (o instanceof String[]) {
          return (String[]) o;
        }
        if (o instanceof String) {
          String s =  (String) o;
          return s.split(",[ ]*");
        }
        else if (o instanceof List) {
          List c = (List) o;
          String[] result = new String[c.size()]; 
          for (int i=0; i <= c.size(); i++) {
            result[i] = String.valueOf(c.get(i));
          }
          return result;
        }
        return new String[0];
    

  }
  
}
